--------------------------------------------------------------
---Create AMLCORE tables, aliases, constraints, and indexes.
--------------------------------------------------------------
--This script is a template for creating the tables, constraints,
--views and indexes required for the 'CORE' AML schema.
--
--This script must be run as a user with SYSADM or DBADM privileges.
--
--This script assumes that two multibank segments are being
--created (BANK1CORE/BANK1KCTR AND BANK2CORE/BANK2KCTR). If more 
--are required then this script must be modified to create each of
--the individual segment schema owner's objects in the additional
--segment schema. We suggest that you copy the DDL for 
--BANK1CORE/BANK1KCTR, substitute your schema name, and run
--the additional statments for each segment added.
--------------------------------------------------------------
--------------------------------------------------------------
SET SCHEMA AMLCORE;

CREATE TABLE AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM
(
	account_number  VARCHAR(50)  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	expected_incoming_amount  NUMERIC(15,5)  ,
	expected_outgoing_amount  NUMERIC(15,5)  ,
	expected_incoming_count  BIGINT  ,
	expected_outgoing_count  BIGINT  ,
	increased_behavior_credit_amt  NUMERIC(15,5)  ,
	increased_behavior_debit_amt  NUMERIC(15,5)  ,
	increased_behavior_credit_cnt  NUMERIC(15,5)  ,
	increased_behavior_debit_cnt  NUMERIC(15,5)  ,
	expected_credit_ceiling_amount  NUMERIC(15,5)  ,
	expected_debit_ceiling_amount  NUMERIC(15,5)  ,
	last_activity_date TIMESTAMP  
) IN TSC_DATA22 INDEX IN TSC_INDEX22;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM IS 'Analytical data captured periodically (as often as client decides).  No history is maintained.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.account_number IS '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_incoming_amount IS 'Currency amount of credits expected to the account during the period (e.g. monthly).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_outgoing_amount IS 'Currency amount of debits expected to the account during the period (e.g. monthly).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_incoming_count IS 'Number of credits expected to the account during the period (e.g. monthly).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_outgoing_count IS 'Number of debits expected to the account during the period (e.g. monthly).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.increased_behavior_credit_amt IS 'A threshold amount above which the behavior of the account is determined to have increased. See scenario SAS10088.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.increased_behavior_debit_amt IS 'A threshold amount above which the behavior of the account is determined to have increased. See scenario SAS10088.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.increased_behavior_credit_cnt IS 'A threshold transaction count above which the behavior of the account is determined to have increased. See scenario SAS10088.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.increased_behavior_debit_cnt IS 'A threshold transaction count above which the behavior of the account is determined to have increased. See scenario SAS10088.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_credit_ceiling_amount IS 'An expected total amount of credits to an account in a given period.  This is determined using the Largest Credit Amount field in the Account Profile.  Used in scenario SAS10091.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.expected_debit_ceiling_amount IS 'An expected total amount of debits to an account in a given period.  This is determined using the Largest Debit Amount field in the Account Profile.  Used in scenario SAS10091.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM.last_activity_date IS 'Date the account last had activity.  Client determines if non-financial transactions should be included (e.g. inquiries), or whether bank-initiated transactions are included, and how often to update this field.'
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM
	ADD CONSTRAINT  XPKFSC_ACCOUNT_ANA  PRIMARY KEY (account_number,segment_id)
;


CREATE TABLE AMLCORE.FSC_ACCOUNT_DIM
(
	account_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	account_number  VARCHAR(50)  NOT NULL,
	line_of_business_name  VARCHAR(35)  ,
	account_type_desc  VARCHAR(20)  NOT NULL,
	account_currency_code  CHAR(3)  NOT NULL,
	account_currency_name  VARCHAR(100)  NOT NULL,
	account_registration_type_desc  VARCHAR(20)  ,
	account_registration_name  VARCHAR(255)  ,
	account_name  VARCHAR(35)  ,
	alternate_name  VARCHAR(35)  ,
	account_open_date TIMESTAMP  ,
	account_close_date TIMESTAMP  ,
	account_status_desc  VARCHAR(35)  ,
	dormant_ind  CHAR(1)  ,
	product_line_name  VARCHAR(35)  ,
	product_category_name  VARCHAR(35)  ,
	product_type_name  VARCHAR(35)  ,
	product_name  VARCHAR(35)  ,
	product_number  VARCHAR(25)  ,
	account_tax_id  VARCHAR(35)  ,
	account_tax_id_type_code  CHAR(1)  ,
	account_tax_state_code  CHAR(3)  ,
	account_primary_branch_name  VARCHAR(25)  ,
	mailing_address_1  VARCHAR(35)  ,
	mailing_address_2  VARCHAR(35)  ,
	mailing_city_name  VARCHAR(35)  ,
	mailing_state_code  CHAR(3)  ,
	mailing_state_name  VARCHAR(35)  ,
	mailing_postal_code  CHAR(10)  ,
	mailing_country_code  CHAR(3)  ,
	mailing_country_name  VARCHAR(100)  ,
	currency_based_account_ind  CHAR(1)  ,
	maturity_date TIMESTAMP  ,
	original_loan_amount  NUMERIC(15,5)  ,
	collateral_type_code  CHARACTER(10)  ,
	collateral_type_desc  VARCHAR(35)  ,
	insured_amount  NUMERIC(15,5)  ,
	employee_ind  CHAR(1)  ,
	letter_of_credit_onfile_ind  CHAR(1)  ,
	cash_intensive_business_ind  CHAR(1)  ,
	trade_finance_ind  CHAR(1)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
)  IN TSC_DATA02 INDEX IN TSC_INDEX02 ;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_DIM IS 'Any financial account of interest to a financial institution for the purposes of detecting anti-money laundering activities.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_number IS '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.line_of_business_name IS 'e.g. General Bank, Corporate & Investment Bank, Capital Management, and
Wealth Management'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_type_desc IS 'Type of Account. 

Legal values are specified in the FSK_LOV table. The starter values shipped with AML are:

"P" - personal
"C" - commercial
"COR" - Correspondent Banking
"MSB" - Money Service Business
"GL" - General Ledger Account

Site-speci'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_currency_code IS 'Currency code in which the account is denominated.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_currency_name IS 'Name of the currency in which the account is denominated e.g. US Dollars.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_registration_type_desc IS 'e.g. Single, Joint, JTWROS'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_registration_name IS 'legal title of account - e.g. "John & Joan Doe IRA JTWROS".'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_name IS 'Account name: Company name or person''s full name

'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.alternate_name IS 'Informal name of account (i.e. not the legal name) e.g. John''s Checking .'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_open_date IS 'Date the account was opened....'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_close_date IS 'Date the account was closed....'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_status_desc IS 'Current state of the account. Starter values are:

Active, Dormant, Closed...'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.dormant_ind IS 'Is the account dormant (Y/N).  Definition of dormant is site-specific e.g. no customer initiated account activity for 2 years.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.product_line_name IS 'The highest level classification of the product of the account.  Starter values are:
BANKING
INVESTING
INSURANCE.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.product_category_name IS 'The second highest level classification of the product of the account.  Starter values are:
BANKING SERVICES
LOANS
RETAIL INVESTING
INSTITUTIONAL INVESTING
LIFE INSURANCE
ANNUITY.
'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.product_type_name IS 'The third highest level classification of the product of the account.  Starter values are: 
CHECKING
SAVINGS
CDS
MONEY MARKET
MORTGAGES
HOME EQUITY
AUTO
STUDENT
PERSONAL
CREDIT CARD
GENERAL INVESTING
RETIREMENT
ESTATE PLANNING
EDUCATION/CUS'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.product_name IS 'Client-specific product name.  e.g. Small Business Optimizer 
'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.product_number IS 'Client''s reference number for a product..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_tax_id IS 'Account tax identification number (no hyphens).

Needs expanding to include foreign tax IDs..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_tax_id_type_code IS 'I - individual or O- Organization tax id format..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_tax_state_code IS 'State/Province in which the account is taxed.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.account_primary_branch_name IS 'Branch which "owns" the account.  This may be different to the account opening branch.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_address_1 IS 'Account Mailing Address - First Line.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_address_2 IS 'Account Mailing Address - Second Line.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_city_name IS 'Account Mailing Address - City.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_state_code IS 'Account Mailing Address - State.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_state_name IS 'Account Mailing Address - State/Province etc.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_postal_code IS 'Account Mailing Address - Post Code.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_country_code IS 'Account Mailing Address - Country (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.mailing_country_name IS 'Mailing Country Name (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.currency_based_account_ind IS 'code or flag designating that you would expect that the majority of transactions would be cash'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.maturity_date IS 'Date loan reaches maturity.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.original_loan_amount IS 'Currency amount of loan at inception.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.collateral_type_code IS 'Type of collateral used to secure a loan.  e.g. CASH, BONDS, REAL ESTATE.

'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.collateral_type_desc IS 'Type of collateral used to secure a loan.  e.g. CASH, BONDS, REAL ESTATE.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.insured_amount IS 'Face value of insurance policy i.e. maximum amount that can be paid in the event of a claim.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.employee_ind IS 'Is the party also an employee of the firm? Y/N.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.change_begin_date IS 'Date from which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.change_end_date IS 'Date to which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_DIM.change_current_ind IS '.Is this the current instance (Y/N)'
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_DIM
	ADD CONSTRAINT  XPKACCOUNT  PRIMARY KEY (account_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1ACCOUNT ON AMLCORE.FSC_ACCOUNT_DIM
(
	account_number  ASC
)
;


CREATE INDEX AMLCORE.XIE2ACCOUNT ON AMLCORE.FSC_ACCOUNT_DIM
(
	account_name  ASC
)
;


CREATE INDEX AMLCORE.XIE3ACCOUNT ON AMLCORE.FSC_ACCOUNT_DIM
(
	account_tax_id  ASC
)
;


CREATE TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
(
	transaction_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	branch_key  BIGINT  NOT NULL,
	time_key  NUMERIC(6)  NOT NULL,
	transaction_type_key  BIGINT  NOT NULL,
	transaction_status_key  NUMERIC(5)  NOT NULL,
	date_key  NUMERIC(8,0)  NOT NULL,
	account_key  BIGINT  NOT NULL,
	country_key  NUMERIC(5)  NOT NULL
) IN TSC_DATA03 INDEX IN TSC_INDEX03 ;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT IS 'Non-financial account transactoins e.g. Address Change, Beneficiary Change, Account Inquiry.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.transaction_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.branch_key IS 'Surrogate identifier'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.transaction_status_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_EVENT_FACT.country_key IS 'System generated surrogate key'
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT  XPKFSC_ACCOUNT_EVE  PRIMARY KEY (transaction_key,segment_id)
;


CREATE INDEX AMLCORE.XIF1FSC_AE_FACT ON AMLCORE.FSC_ACCOUNT_EVENT_FACT
(
	account_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF2FSC_AE_FACT ON AMLCORE.FSC_ACCOUNT_EVENT_FACT
(
	date_key  ASC,
	segment_id ASC
);



CREATE TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT
(
	account_number  VARCHAR(50)  NOT NULL,
	month_key  NUMERIC(6,0)  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	transactions_count  NUMERIC(10,0)  ,
	deposits_count  NUMERIC(10,0)  ,
	withdrawals_count  NUMERIC(10,0)  ,
	wires_count  NUMERIC(10,0)  ,
	cash_transactions_count  NUMERIC(10,0)  ,
	account_value_amount  NUMERIC(18,5)  ,
	total_transactions_amount  NUMERIC(18,5)  ,
	total_credits_amount  NUMERIC(18,5)  ,
	total_debits_amount  NUMERIC(18,5)  ,
	total_cash_debits_amount  NUMERIC(18,5)  ,
	total_cash_credits_amount  NUMERIC(18,5)  ,
	total_wire_credits_amount  NUMERIC(18,5)  ,
	total_wire_debits_amount  NUMERIC(18,5)  ,
	beginning_balance_amount  NUMERIC(18,5)  ,
	average_daily_balance_amount  NUMERIC(18,5)  ,
	ending_cash_balance_amount  NUMERIC(18,5)  ,
	max_account_value_amount  NUMERIC(18,5)  ,
	min_account_value_amount  NUMERIC(18,5)  ,
	avg_account_value_amount  NUMERIC(18,5)  ,
	cust_initiated_trans_count  BIGINT  ,
	largest_credit_amount  NUMERIC(18,5)  ,
	largest_debit_amount  NUMERIC(18,5)  
)  IN TSC_DATA04 INDEX IN TSC_INDEX04;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT IS 'A monthly snapshot of an account''s transactional activity.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.account_number IS '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.month_key IS 'Meaningful surrogate key of format yyyymm.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.transactions_count IS 'Total number of transactions in the account during the profile period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.deposits_count IS 'Total number of deposits in the account during the profile period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.withdrawals_count IS 'Total number of withdrawals in the account during the profile period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.wires_count IS 'Total number of wires (in and out) in the account during the profile period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.cash_transactions_count IS 'Total number of cash transactions in the account during the profile period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.account_value_amount IS 'Total Account Market Value at end of period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_transactions_amount IS 'Total money amount of all transactions (add up all debits and credits).'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_credits_amount IS 'Total credits ($) to the account duing the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_debits_amount IS 'Total debits ($) to the account during the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_cash_debits_amount IS 'Total Cash debits ($) to the account during the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_cash_credits_amount IS 'Total Cash credits ($) to the account during the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_wire_credits_amount IS 'Total Wire Credits ($) to the account during the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.total_wire_debits_amount IS 'Total Wire debits ($) to the account during the period..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.beginning_balance_amount IS 'Balance at the beginning of the period.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.average_daily_balance_amount IS 'Average Daily balance during the period.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.ending_cash_balance_amount IS 'Balance at the end of the period. This refers only to the ''cash'' portion of brokerage accounts. It does not include the cash value of their securities.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.max_account_value_amount IS 'Maximum value of account during the month.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.min_account_value_amount IS 'Minimum value of account during the month.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.avg_account_value_amount IS 'Average value of account during the month.  Includes value of securities as well as cash therefore is different to average_daily_balance_amount.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.cust_initiated_trans_count IS 'Number of transactions initiated by the customer (vs. by the bank) during the month.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.largest_credit_amount IS 'The amount of the largest single credit in specified month.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_PROFILE_FACT.largest_debit_amount IS 'The amount of the largest single debit in specified month.'
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT
	ADD CONSTRAINT  XPKACCOUNT_SUMMARY  PRIMARY KEY (account_number,month_key,segment_id)
;


CREATE TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
(
	transaction_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	account_key  BIGINT  NOT NULL,
	branch_key  BIGINT  NOT NULL,
	transaction_type_key  BIGINT  NOT NULL,
	transaction_status_key  NUMERIC(5)  NOT NULL,
	trade_date_key  NUMERIC(8,0)  NOT NULL,
	execution_time_key  NUMERIC(6)  NOT NULL,
	posted_date_key  NUMERIC(8)  NOT NULL,
	settlement_date_key  NUMERIC(8,0)  NOT NULL,
	quantity_executed  NUMERIC(15,5)  ,
	execution_price  NUMERIC(10,5)  ,
	transaction_currency_key  NUMERIC(5)  NOT NULL,
	principal_amount_in_txn_ccy  NUMERIC(15,5)  ,
	principal_amount  NUMERIC(15,5)  ,
	principal_amount_in_acct_ccy  NUMERIC(15,5)  NOT NULL,
	associate_key  BIGINT  
) IN TSC_DATA05 INDEX IN TSC_INDEX05;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT IS 'A record of brokerage trading transactions.  e.g. buying and selling equities.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.transaction_key IS 'Surrogate key..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.branch_key IS 'Surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.transaction_status_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.trade_date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.execution_time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.posted_date_key IS 'Date the trade was posted to the system.  e.g. the trade could occur Thursday PM but due to system outages the trades don''t get posted until Friday AM.

'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.settlement_date_key IS 'Date the trade was settled.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.quantity_executed IS 'Quantity actually purchased/sold.  Could be different to quantity ordered i.e. partial fills?'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.execution_price IS 'Price at which the trade was executed.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.transaction_currency_key IS 'Surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.principal_amount_in_txn_ccy IS 'aka trade amount in txn currency e.g. EUR 10,000'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.principal_amount IS 'aka trade amount in base currency e.g. $10,000.  Principal amount is the face value of security traded.  e.g. Buy 10,000 of bond X at price $980 - the principal amount is 10,000.  The gross amount of the trade is $9,800 plus any accrued interest.

For '
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.principal_amount_in_acct_ccy IS 'The amount of the transaction in the denomination currency of the account.'
;


COMMENT ON COLUMN AMLCORE.FSC_ACCOUNT_TRADE_FACT.associate_key IS 'System generated surrogate identifier'
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT  XPKACCOUNT_POSITIO  PRIMARY KEY (transaction_key,segment_id)
;


CREATE INDEX AMLCORE.XIF1ACC_TRD_FACT ON AMLCORE.FSC_ACCOUNT_TRADE_FACT
(
	account_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF2ACC_TRD_FACT ON AMLCORE.FSC_ACCOUNT_TRADE_FACT
(
	trade_date_key  ASC,
	segment_id  ASC
);



CREATE TABLE AMLCORE.FSC_ASSOCIATE_DIM
(
	associate_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	associate_number  VARCHAR(20)  ,
	associate_first_name  VARCHAR(35)  ,
	associate_last_name  VARCHAR(35)  ,
	associate_middle_name  VARCHAR(25)  ,
	associate_title_desc  VARCHAR(50)  ,
	associate_status_desc  VARCHAR(35)  ,
	street_address_1  VARCHAR(35)  ,
	street_address_2  VARCHAR(35)  ,
	street_city_name  VARCHAR(35)  ,
	street_state_code  CHAR(3)  ,
	street_state_name  VARCHAR(35)  ,
	street_postal_code  CHAR(10)  ,
	street_country_name  VARCHAR(100)  ,
	street_country_code  CHAR(3)  ,
	work_phone_number  VARCHAR(25)  ,
	email_address  VARCHAR(35)  ,
	branch_number  VARCHAR(25)  ,
	branch_name  VARCHAR(35)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA06 INDEX IN TSC_INDEX06 ;


COMMENT ON TABLE AMLCORE.FSC_ASSOCIATE_DIM IS 'An associate of the financial institution who has played a role in the execution of a transaction or plays a role in the managment of an account.  e.g. Teller, Insurance Agent, Account Manager.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_number IS 'Firm-assigned associate identifier/employee number.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_first_name IS 'Associate First Name'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_last_name IS 'Associate Last Name'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_middle_name IS 'Associate Middle Name'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_title_desc IS 'Associate Title

Sample data had a 39 char length.  Made it 50.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.associate_status_desc IS 'Active, Terminated etc?
'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_address_1 IS 'Associate''s Address Line 1'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_address_2 IS 'Associate''s Address Line 2'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_city_name IS 'Associate''s Address - City'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_state_code IS 'Associate''s Address - State Code'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_state_name IS 'Associate''s Address - State/Province Name.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_postal_code IS 'Associate''s Address - Postal Code'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_country_name IS 'Associate''s Address - Country (ISO)

'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.street_country_code IS 'Associate''s Address - Country (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.work_phone_number IS '(XXX) XXX - XXXX'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.email_address IS 'XXXXXXXX@abc.com'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.branch_number IS 'Associate''s branch number - if associated with a specific branch e.g. a teller.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.branch_name IS 'Associate''s branch name.'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.change_begin_date IS 'Date from which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.change_end_date IS 'Date to which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_ASSOCIATE_DIM.change_current_ind IS 'Is this the current instance (Y/N).'
;


ALTER TABLE AMLCORE.FSC_ASSOCIATE_DIM
	ADD CONSTRAINT  XPKASSOCIATE  PRIMARY KEY (associate_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1ASSOCIATE ON AMLCORE.FSC_ASSOCIATE_DIM
(
	associate_number  ASC
)
;


CREATE INDEX AMLCORE.XIE6ASSOCIATE ON AMLCORE.FSC_ASSOCIATE_DIM
(
	associate_last_name  ASC
)
;


CREATE TABLE AMLCORE.FSC_BANK_DIM
(
	bank_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	bank_number  VARCHAR(25)  ,
	bank_chips_number  VARCHAR(25)  ,
	bank_swift_number  VARCHAR(25)  ,
	bank_name  VARCHAR(35)  ,
	bank_address_1  VARCHAR(35)  ,
	bank_address_2  VARCHAR(35)  ,
	bank_city_name  VARCHAR(35)  ,
	bank_state_code  CHAR(3)  ,
	bank_state_name  VARCHAR(35)  ,
	bank_postal_code  CHAR(10)  ,
	bank_country_code  CHAR(3)  ,
	bank_country_name  CHAR(35)  ,
	bank_phone_number  VARCHAR(25)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL,
	change_current_ind  CHAR(1)  NOT NULL
)  IN TSC_DATA01 INDEX IN TSC_INDEX01;


COMMENT ON TABLE AMLCORE.FSC_BANK_DIM IS 'Describes a banking organization.  It may be an external bank or a unit of the client''s organization.'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_number IS 'Banks routing number e.g. ABA number'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_chips_number IS 'Banks number in CHIPS wire system'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_swift_number IS 'Banks number in SWIFT wire system'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_name IS 'Bank name'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_address_1 IS 'Bank Address Line 1'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_address_2 IS 'Bank Address Line 2'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_city_name IS 'Bank City'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_state_code IS 'Bank State'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_state_name IS 'Bank State/Province etc'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_postal_code IS 'Bank Postal Code'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_country_code IS 'Bank country (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_country_name IS 'This is really Bank Country Code (ISO)

Should be a name and a code separately.'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.bank_phone_number IS 'Bank Phone Number'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.change_begin_date IS 'Date from which this row was valid.'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.change_end_date IS 'Date to which this row was valid.'
;


COMMENT ON COLUMN AMLCORE.FSC_BANK_DIM.change_current_ind IS 'Is this the current instance (Y/N)'
;


ALTER TABLE AMLCORE.FSC_BANK_DIM
	ADD CONSTRAINT  XPKBANK  PRIMARY KEY (bank_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1BANK ON AMLCORE.FSC_BANK_DIM
(
	bank_number  ASC,
	segment_id ASC
)
;


CREATE TABLE AMLCORE.FSC_BRANCH_DIM
(
	branch_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	branch_type_desc  VARCHAR(10)  ,
	branch_number  VARCHAR(40)  ,
	branch_name  VARCHAR(100)  ,
	street_address_1  VARCHAR(35)  ,
	street_address_2  VARCHAR(35)  ,
	street_city_name  VARCHAR(35)  ,
	street_state_code  CHAR(3)  ,
	street_state_name  VARCHAR(35)  ,
	street_postal_code  CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA01 INDEX IN TSC_INDEX01;


COMMENT ON TABLE AMLCORE.FSC_BRANCH_DIM IS 'The location of the execution of a transaction.  e.g. Branch #123, ATM #3343433'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.branch_key IS 'Surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.branch_type_desc IS '"BRANCH" or "ATM" or "POS".  Used until Branch/ATM/Location are remodelled.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.branch_number IS 'Source System identifier for branches.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.branch_name IS 'Branch Name.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_address_1 IS 'Physical Address - Line 1.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_address_2 IS 'Physical Address - Line 2.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_city_name IS 'Physical Address - City.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_state_code IS 'Address State.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_state_name IS 'State/Province etc name..'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_postal_code IS 'Address - Postal Code.'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_country_code IS 'Address - Country Code'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.street_country_name IS 'Address - Country Name'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.change_begin_date IS 'Date from which this row was valid..
'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.change_end_date IS 'Date to which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_BRANCH_DIM.change_current_ind IS 'Is this the current instance (Y/N).
'
;


ALTER TABLE AMLCORE.FSC_BRANCH_DIM
	ADD CONSTRAINT  XPKBRANCH  PRIMARY KEY (branch_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1BRANCH ON AMLCORE.FSC_BRANCH_DIM
(
	branch_number  ASC
)
;


CREATE INDEX AMLCORE.XIE2BRANCH ON AMLCORE.FSC_BRANCH_DIM
(
	branch_name  ASC
)
;


CREATE TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key  BIGINT  NOT NULL,
	transaction_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	role_desc  VARCHAR(20)  ,
	sequence_number  NUMERIC(2)  
) IN TSC_DATA07 INDEX IN TSC_INDEX07;


COMMENT ON TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE IS 'A record of which banks play a role on a given cash flow transaction.  Roles include REMITTER and BENEFICIARY.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE.bank_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE.transaction_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE.role_desc IS 'Role that the bank plays in the transaction.

Starter Values are:
BENEFICIARY
REMITTER
CORRESPONDENT
INTERMEDIARY

Note: Likely not possible to be able to differentiate between correspondent and intermediary - probably best to just use intermedia'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE.sequence_number IS 'Order in which the bank handled the monies.'
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD CONSTRAINT  XPKFSC_CASH_FLOW_B  PRIMARY KEY (bank_key,transaction_key,segment_id)
;

CREATE INDEX AMLCORE.XIF1CFF_BRIDGE ON AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key  ASC,
	segment_id  ASC
);

CREATE INDEX AMLCORE.XIF2CFF_BRIDGE ON AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	transaction_key  ASC,
	segment_id  ASC
);

CREATE TABLE AMLCORE.FSC_CASH_FLOW_FACT
(
	transaction_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	account_key  BIGINT  NOT NULL,
	country_key  NUMERIC(5)  NOT NULL,
	transaction_type_key  BIGINT  NOT NULL,
	time_key  NUMERIC(6)  NOT NULL,
	date_key  NUMERIC(8,0)  NOT NULL,
	transaction_status_key  NUMERIC(5)  NOT NULL,
	transaction_currency_key  NUMERIC(5)  NOT NULL,
	branch_key  BIGINT  NOT NULL,
	remitter_ext_party_key  BIGINT  NOT NULL,
	beneficiary_ext_party_key  BIGINT  NOT NULL,
	posted_date_key  NUMERIC(8)  ,
	associate_key  BIGINT  NOT NULL,
	executing_party_key  BIGINT  NOT NULL,
	currency_amount  NUMERIC(15,5)  NOT NULL,
	currency_amount_in_txn_ccy  NUMERIC(15,5)  NOT NULL,
	currency_amount_in_account_ccy  NUMERIC(15,5)  NOT NULL,
	secondary_account_key  BIGINT  NOT NULL,
	related_ind  CHAR(1)  NOT NULL DEFAULT 'U',
	third_party_ind  CHAR(1)  
)  IN TSC_DATA08 INDEX IN TSC_INDEX08;


CREATE INDEX AMLCORE.XIF1ACCOUNT_CREDITS_FACT ON AMLCORE.FSC_CASH_FLOW_FACT
(
	account_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF12ACCOUNT_CREDITS_FACT ON AMLCORE.FSC_CASH_FLOW_FACT
(
	executing_party_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF15ACCOUNT_CREDITS_FACT ON AMLCORE.FSC_CASH_FLOW_FACT
(
	remitter_ext_party_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF16ACCOUNT_CREDITS_FACT ON AMLCORE.FSC_CASH_FLOW_FACT
(
	beneficiary_ext_party_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF5ACCOUNT_CREDITS_FACT ON AMLCORE.FSC_CASH_FLOW_FACT
(
	date_key  ASC,
	segment_id ASC
);



COMMENT ON TABLE AMLCORE.FSC_CASH_FLOW_FACT IS 'Any debit or credit to an account.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.transaction_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.country_key IS 'Country where transaction occurred.  This is a short-cut primarily for wires to avoid having to query the wire dimensions..'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.transaction_status_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.transaction_currency_key IS 'Original transaction currency..'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.branch_key IS 'Surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.remitter_ext_party_key IS 'Surrogate identifier.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.beneficiary_ext_party_key IS 'Surrogate identifier.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.posted_date_key IS 'Date the transaction was posted to the source system.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.associate_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.executing_party_key IS 'Party that initiated the transaction.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.currency_amount IS 'Amount of the transaction expressed in the base/reporting currency..'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.currency_amount_in_txn_ccy IS 'Amount of the transaction expressed in the original currency of the transaction..'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.currency_amount_in_account_ccy IS 'The amount of the transaction in the denomination currency of the account.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.secondary_account_key IS 'Used to identify a secondary internal account associated with an internal transfer.  e.g. for a  transfer from savings to checking, the savings account is account_key, the checking account is secondary_account_key.  If not used set to -1.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.related_ind IS 'Is the transaction between two related accounts e.g. a transfer between one person''s checking and savings accounts or a wire between spouses.  This flag must be set by the ETL - it cannot be derived.'
;


COMMENT ON COLUMN AMLCORE.FSC_CASH_FLOW_FACT.third_party_ind IS 'Is there a thrid party (i.e. non-customer) associated with this transaction Y/N.'
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT  XPKACCOUNT_CREDITS  PRIMARY KEY (transaction_key,segment_id)
;


CREATE TABLE AMLCORE.FSC_CLASSIFIER_FACT
(
	party_number  VARCHAR(50)  NOT NULL,
	month_key  NUMERIC(6,0)  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	rc_pep  NUMERIC(1)  ,
	rc_foreign_financial_inst  NUMERIC(1)  ,
	rc_non_bank_financial_inst  NUMERIC(1)  ,
	rc_foreign_corporation  NUMERIC(1)  ,
	rc_deposit_broker  NUMERIC(1)  ,
	rc_cash_intensive_business  NUMERIC(1)  ,
	rc_professional_svcs_provider  NUMERIC(1)  ,
	rc_private_banking  NUMERIC(1)  ,
	rc_trust_or_asset_mgmt_acct  NUMERIC(1)  ,
	rc_foreign_correspondent_acct  NUMERIC(1)  ,
	rc_trade_finance  NUMERIC(1)  ,
	rc_special_use_account  NUMERIC(1)  ,
	rc_lending_activity  NUMERIC(1)  ,
	rc_nondeposit_account  NUMERIC(1)  ,
	rc_wires_count  NUMERIC(6)  ,
	rc_funds_transfer_count  NUMERIC(6)  ,
	rc_non_profit_org  NUMERIC(1)  ,
	rc_funds_payment_svcs_count  NUMERIC(6)  ,
	rc_internal_pep  NUMERIC(1)  ,
	rc_high_risk_geography  NUMERIC(1)  ,
	rc_monetary_instrument_count  NUMERIC(6)  
) IN TSC_DATA08 INDEX IN TSC_INDEX08 ;



COMMENT ON TABLE AMLCORE.FSC_CLASSIFIER_FACT IS 'A monthly snapshot of a the risk classification factors for a customer.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_pep IS 'Classifier based on politically_exposed_person_ind column in fsc_party_dim.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_professional_svcs_provider IS 'Classifier based on partys status as a Professional Service Provider (e.g. attorney, CPA)';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_deposit_broker IS 'Classifer based on whether or not the customer is a deposit broker.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_non_bank_financial_inst IS 'Classifer based on whether or not the customer is a non bank financial institution.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_foreign_corporation IS 'Classifer based on whether or not the customer is a foreign corporation.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_cash_intensive_business IS 'Classifer based on whether or not the customer is a cash intensive business.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_private_banking IS 'Classifer based on whether or not the customer engaged in private banking.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_trust_or_asset_mgmt_acct IS 'Classifer based on whether or not the customer has a trust or asset management account.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_foreign_correspondent_acct IS 'Classifer based on whether or not the customer is a foreign correspondent account.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_special_use_account IS 'Classifer based on whether or not the customer is a special use account.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_lending_activity IS 'Classifer based on whether or not the customer engaged in lending activity.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_nondeposit_account IS 'Classifer based on whether or not the customer is a nondeposit account.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.month_key IS 'Meaningful surrogate key of format yyyymm.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.party_number IS 'Stores intermediate data used by Risk Classification to produce Risk Assessments. This table will contain one record for each party for a given month_key.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_wires_count IS 'Classifer based on number of wires in this period.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_funds_transfer_count IS 'Classifer based on the number of funds transfers in this period.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_non_profit_org IS 'Classifer based on whether or not the customer is a non profit organization.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_internal_pep IS 'Classifier based on a customer-supplied list of persons stored in fsk_list.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_high_risk_geography IS 'Classifer based on whether or not the customer is associated with a high risk geography.';



COMMENT ON COLUMN AMLCORE.FSC_CLASSIFIER_FACT.rc_monetary_instrument_count IS 'Classifer based on number of monetary instruments associated with the party in this month.';


ALTER TABLE AMLCORE.FSC_CLASSIFIER_FACT
	ADD CONSTRAINT  XPKFSC_CLASSIFIER_  PRIMARY KEY (party_number,month_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1FSC_CLASSIFIER ON AMLCORE.FSC_CLASSIFIER_FACT
(
	rc_pep  ASC
)
;


CREATE TABLE AMLCORE.FSC_COUNTRY_DIM
(
	country_key  NUMERIC(5)  NOT NULL,
	country_code_2  CHAR(2)  ,
	country_code_3  CHAR(3)  ,
	country_name  VARCHAR(100)  
) IN TSC_DATA01 INDEX IN TSC_INDEX01 ;


COMMENT ON TABLE AMLCORE.FSC_COUNTRY_DIM IS 'Country Codes. Shipped with recent version of ISO country codes.'
;


COMMENT ON COLUMN AMLCORE.FSC_COUNTRY_DIM.country_key IS 'System generated surrogate key..'
;


COMMENT ON COLUMN AMLCORE.FSC_COUNTRY_DIM.country_code_2 IS 'ISO 2 character country code.  e.g. US.'
;


COMMENT ON COLUMN AMLCORE.FSC_COUNTRY_DIM.country_code_3 IS 'ISO 3 character country code.  e.g. USA.'
;


COMMENT ON COLUMN AMLCORE.FSC_COUNTRY_DIM.country_name IS 'ISO Country Name..'
;


ALTER TABLE AMLCORE.FSC_COUNTRY_DIM
	ADD CONSTRAINT  XPKFSC_COUNTRY_DIM  PRIMARY KEY (country_key)
;


CREATE INDEX AMLCORE.XIE1FSC_COUNTRY_DI ON AMLCORE.FSC_COUNTRY_DIM
(
	country_name  ASC
)
;


CREATE INDEX AMLCORE.XIE2FSC_COUNTRY_DI ON AMLCORE.FSC_COUNTRY_DIM
(
	country_code_2  ASC
)
;


CREATE INDEX AMLCORE.XIE3FSC_COUNTRY_DI ON AMLCORE.FSC_COUNTRY_DIM
(
	country_code_3  ASC
)
;


CREATE TABLE AMLCORE.FSC_CURRENCY_DIM
(
	currency_key  NUMERIC(5)  NOT NULL,
	currency_code  CHAR(3)  ,
	currency_name  VARCHAR(100)  
)  IN TSC_DATA01 INDEX IN TSC_INDEX01 ;


COMMENT ON TABLE AMLCORE.FSC_CURRENCY_DIM IS 'Currency Codes.  Shipped with recent version of the ISO Currency Codes.'
;


COMMENT ON COLUMN AMLCORE.FSC_CURRENCY_DIM.currency_key IS 'Surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_CURRENCY_DIM.currency_code IS 'ISO 4217 3 character currency code e.g. USD.'
;


COMMENT ON COLUMN AMLCORE.FSC_CURRENCY_DIM.currency_name IS 'Name of currency e.g. US Dollars.'
;


ALTER TABLE AMLCORE.FSC_CURRENCY_DIM
	ADD CONSTRAINT  XPKFSC_CURRENCY_DI  PRIMARY KEY (currency_key)
;


CREATE INDEX AMLCORE.XIE1FSC_CURRENCY_D ON AMLCORE.FSC_CURRENCY_DIM
(
	currency_code  ASC
)
;


CREATE TABLE AMLCORE.FSC_DATE_DIM
(
	date_key  NUMERIC(8,0)  NOT NULL,
	calendar_date TIMESTAMP  ,
	calendar_date_sas  NUMERIC(8,0)  ,
	calendar_date_dmy  CHAR(9)  ,
	day_name  VARCHAR(9)  ,
	day_name_short  CHAR(3)  ,
	day_number_in_month  NUMERIC(2,0)  ,
	day_number_in_year  NUMERIC(3,0)  ,
	week_number_in_month  NUMERIC(1,0)  ,
	week_number_in_year  NUMERIC(2,0)  ,
	month_number_in_year  NUMERIC(2,0)  ,
	month_key  NUMERIC(6,0)  ,
	month_and_year  CHAR(6)  ,
	month_name  VARCHAR(9)  ,
	month_name_short  CHAR(3)  ,
	quarter_name  CHAR(4)  ,
	quarter_and_year  CHAR(6)  ,
	month_name_3c  CHAR(3)  ,
	quarter_name_2c  CHAR(2)  ,
	quarter_name_4c  CHAR(4)  ,
	year_2c  CHAR(2)  ,
	year_4c  CHAR(4)  ,
	holiday_ind  CHAR(1)  ,
	holiday_name  CHAR(9)  ,
	week_day_ind  CHAR(1)  ,
	end_of_month_ind  CHAR(1)  ,
	economic_release_desc  VARCHAR(20)  ,
	economic_event_desc  VARCHAR(20)  
)  IN TSC_DATA01 INDEX IN TSC_INDEX01 ;


COMMENT ON TABLE AMLCORE.FSC_DATE_DIM IS 'Calendar date table.'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.calendar_date IS 'The calendar date e.g. 3/18/2003.'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.calendar_date_sas IS 'SAS formatted date.'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.calendar_date_dmy IS 'Calendar date in DD/MM/YYYY format'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.day_name IS 'Which day of the week is it?  e.g. Monday'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.day_name_short IS 'Abbreviated day of week name e.g. Mon'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.day_number_in_month IS 'Which day of the month it is e.g. 23(rd)'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.day_number_in_year IS 'Which (Julian) day of the year it is e.g. 234'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.week_number_in_month IS 'Which week of the month it is e.g. 3(rd week)'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.week_number_in_year IS 'Which week of the year it is e.g. 52(nd)'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_number_in_year IS 'Number of the month e.g. 3(March)'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_key IS 'Foreign Key to the MONTH_DIM table'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_and_year IS 'Month and Year combined e.g. 032003 (March 2003)'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_name IS 'Name of Month e.g. March'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_name_short IS 'Abbreviated month name e.g. MAR'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.quarter_name IS 'Which quarter this date falls in e.g. Q1'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.quarter_and_year IS 'Quarter and Year combined e.g. Q22003'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.month_name_3c IS '3 Char month name e.g. MAR'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.quarter_name_2c IS '2 Character quarter name e.g. Q2'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.quarter_name_4c IS '4 Char quarter name e.g. QTR4'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.year_2c IS 'Two character year e.g. 03'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.year_4c IS '4 char year e.g. 2003'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.holiday_ind IS 'Is this day a holiday for the bank? Y/N'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.holiday_name IS 'If a holiday which holiday is it?  e.g. Independence Day'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.week_day_ind IS 'Is this day a weekday? Y/N'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.end_of_month_ind IS 'Is this day the last day of the month Y/N'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.economic_release_desc IS 'release is a economic release by the government. ie.

gdp,
michigan sentiment,
housing starts
fed omc
etc.'
;


COMMENT ON COLUMN AMLCORE.FSC_DATE_DIM.economic_event_desc IS 'events, are non planned

ie. rate changes, etc.'
;


ALTER TABLE AMLCORE.FSC_DATE_DIM
	ADD CONSTRAINT  PKX01_DATE_KEY  PRIMARY KEY (date_key)
;


CREATE UNIQUE INDEX AMLCORE.AKX01_CALENDAR_DAT ON AMLCORE.FSC_DATE_DIM
(
	calendar_date  ASC
)
;


CREATE UNIQUE INDEX AMLCORE.AKX02_CALENDAR_DAT ON AMLCORE.FSC_DATE_DIM
(
	calendar_date_dmy  ASC
)
;


CREATE UNIQUE INDEX AMLCORE.AKX03_CALENDAR_DAT ON AMLCORE.FSC_DATE_DIM
(
	calendar_date_sas  ASC
)
;


CREATE TABLE AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_key  BIGINT  NOT NULL,
	entity_watch_list_number  VARCHAR(35)  NOT NULL,
	watch_list_name  CHAR(4)  NOT NULL,
	category_desc  VARCHAR(50)  ,
	type_desc  VARCHAR(20)  ,
	programs  VARCHAR(250)  ,
	tax_id  VARCHAR(35)  ,
	tax_id_type_code  CHAR(1)  ,
	identification_id  VARCHAR(35)  ,
	identification_type_desc  VARCHAR(35)  ,
	date_of_birth TIMESTAMP  ,
	year_of_birth  NUMERIC(4)  ,
	place_of_birth  VARCHAR(100)  ,
	deceased_ind  CHAR(1)  ,
	first_name  VARCHAR(50)  ,
	last_name  VARCHAR(50)  ,
	middle_name  VARCHAR(100)  ,
	entity_name  VARCHAR(200)  ,
	match_code_individual  VARCHAR(15)  ,
	match_code_organization  VARCHAR(20)  ,
	entity_title  VARCHAR(200)  ,
	occupation_desc  VARCHAR(200)  ,
	address  VARCHAR(100)  ,
	city_name  VARCHAR(50)  ,
	state_name  VARCHAR(50)  ,
	postal_code  CHAR(10)  ,
	country_code  CHAR(3)  ,
	country_name  VARCHAR(100)  ,
	full_address  VARCHAR(300)  ,
	match_code_full_address  VARCHAR(40)  ,
	citizenship_country_code  CHAR(3)  ,
	citizenship_country_name  VARCHAR(100)  ,
	match_code_citizenship  VARCHAR(15)  ,
	nationality_country_code  CHAR(3)  ,
	nationality_country_name  VARCHAR(100)  ,
	match_code_nationality  VARCHAR(15)  ,
	org_country_of_business_code  VARCHAR(3)  ,
	org_country_of_business_name  VARCHAR(100)  ,
	match_code_org_country  VARCHAR(15)  ,
	politically_exposed_person_ind  CHAR(1)  ,
	create_date TIMESTAMP  ,
	update_date TIMESTAMP  ,
	exclude_ind  CHAR(1)  NOT NULL,
	change_begin_date TIMESTAMP  NOT NULL,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA10 INDEX IN TSC_INDEX10 ;


COMMENT ON TABLE AMLCORE.FSC_ENTITY_WATCH_LIST_DIM IS 'External entities of interest for AML monitoring purposes obtained from publicly sourced lists.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.entity_watch_list_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.entity_watch_list_number IS 'Natural key for an individual list entry from source.  e.g. WorldCheck = UID.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.watch_list_name IS 'Four character code for watch list.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.category_desc IS 'e.g. TERRORIST ORGANIZATION, PEP..'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.tax_id IS 'tax identification number - used as a means of unqiuely identifying an individual or organization. e.g. is USA SSN.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.first_name IS 'First name of an individual.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.last_name IS 'Last name of an individual'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.middle_name IS 'Middle name of an individual.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.match_code_individual IS 'Match code names for individuals.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.match_code_organization IS 'Match code column for orginization names.'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.politically_exposed_person_ind IS 'Is this person in a senior political position or related to a senior political person in some way? Y/N'
;


COMMENT ON COLUMN AMLCORE.FSC_ENTITY_WATCH_LIST_DIM.exclude_ind IS 'Flag which user can set to exclude this entity from watch list analysis.'
;


ALTER TABLE AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
	ADD CONSTRAINT  XPKFSC_ENTITY_WATC  PRIMARY KEY (entity_watch_list_key)
;


CREATE INDEX AMLCORE.XIE1FSC_ENTITY_WAT ON AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_number  ASC
)
;


CREATE INDEX AMLCORE.XIE4FSC_ENTITY_WAT ON AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	last_name  ASC
)
;


CREATE INDEX AMLCORE.XIE2FSC_ENTITY_WAT ON AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	watch_list_name  ASC
)
;


CREATE TABLE AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	ext_party_account_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	external_party_number  VARCHAR(100)  ,
	ext_party_type_desc  VARCHAR(20)  ,
	full_name  VARCHAR(35)  ,
	last_name  VARCHAR(35)  ,
	first_name  VARCHAR(35)  ,
	middle_name  VARCHAR(35)  ,
	birth_date TIMESTAMP  ,
	party_tax_id  VARCHAR(35)  ,
	party_tax_id_type_code  CHAR(1)  ,
	match_code_organization  CHAR(20)  ,
	match_code_individual  CHAR(15)  ,
	match_code_street_address  CHAR(40)  ,
	street_address_1  VARCHAR(35)  ,
	street_address_2  VARCHAR(35)  ,
	street_city_name  VARCHAR(35)  ,
	street_state_code  CHAR(3)  ,
	street_state_name  VARCHAR(35)  ,
	street_postal_code  CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	account_number  VARCHAR(50)  ,
	bank_key  BIGINT  ,
	branch_number  VARCHAR(25)  ,
	branch_name  VARCHAR(35)  ,
	citizenship_country_code  CHAR(3)  ,
	citizenship_country_name  VARCHAR(100)  ,
	residence_country_code  CHAR(3)  ,
	residence_country_name  VARCHAR(100)  ,
	phone_number_1  VARCHAR(25)  ,
	phone_number_2  VARCHAR(25)  ,
	identification_id  VARCHAR(35)  ,
	identification_type_desc  CHAR(4)  ,
	identification_state_code  CHAR(3)  ,
	identification_country_code  CHAR(3)  ,
	identification_country_name  VARCHAR(100)  
) IN TSC_DATA11 INDEX IN TSC_INDEX11 ;


COMMENT ON TABLE AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM IS 'Facts about an external party (i.e. non-customer, organization or individual) captured on a transaction e.g. wire remitter or beneficiary.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.ext_party_account_key IS 'Surrogate identifier.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.external_party_number IS 'External identifier of the external party.  If available could use tax id.  If not available, could use the transaction reference number.

'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.ext_party_type_desc IS '"INDIVIDUAL" or "ORGANIZATION"'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.full_name IS 'Either organization name or concatenation of first, middle and last names of an individual.

'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.last_name IS 'Individuals last name.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.first_name IS 'Individuals first name.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.middle_name IS 'Individuals middle name.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.birth_date IS 'Customer date of birth'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.party_tax_id IS 'Tax Identification Number.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.party_tax_id_type_code IS 'E (EIN)  or S(SSN).'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.match_code_organization IS 'Generic match code.  Use is site-specific, but could be used to match name to watch lists.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.match_code_individual IS 'Match code names for individuals.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.match_code_street_address IS 'Match code address for individuals or organizations.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_address_1 IS 'External address line 1 - of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_address_2 IS 'External address line 2 - of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_city_name IS 'External city name - of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_state_code IS 'External address state/province code - of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_state_name IS 'External state/province name - of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_postal_code IS 'Postal code.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_country_code IS 'External country code (ISO) of the individual/org'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.street_country_name IS 'External country name (ISO) of the individual/org.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.account_number IS 'Account number the funds are sourced from/targetted to.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.branch_number IS 'External branch number.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.branch_name IS 'External branch name.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.citizenship_country_code IS 'Country of Citizenship (ISO-3) for individual'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.citizenship_country_name IS 'Country of citizenship - name - for individual (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.residence_country_code IS 'Country of residence (ISO-3) for an individual'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.residence_country_name IS 'Name of Country of residence for individual (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.phone_number_1 IS 'Customer Phone Number 1'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.phone_number_2 IS 'Customer Phone 2'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.identification_id IS 'Customer identification number used to open account e.g. driver''s license number.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.identification_type_desc IS 'Starter Values:

dl - drivers license
mili - military
pass - passport
empl - employee id
gc - green card
govt - goverment
schl - school id
stid - state id
unid - union id'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.identification_state_code IS 'State of Driver''s license if license used for id in account opening process.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.identification_country_code IS 'Country of ID used to open account.'
;


COMMENT ON COLUMN AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM.identification_country_name IS 'Country of ID used to open account.'
;


ALTER TABLE AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
	ADD CONSTRAINT  XPKFSC_EXTERNAL_PA  PRIMARY KEY (ext_party_account_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1FSC_EXTERNAL_P ON AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	external_party_number  ASC
)
;


CREATE INDEX AMLCORE.XIE2FSC_EXTERNAL_P ON AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	last_name  ASC
)
;


CREATE INDEX AMLCORE.XIE4FSC_EXTERNAL_P ON AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	account_number  ASC
)
;


CREATE INDEX AMLCORE.XIE5FSC_EXTERNAL_P ON AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	full_name  ASC
)
;


CREATE TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key  BIGINT  NOT NULL,
	account_key  BIGINT  NOT NULL,
	change_begin_date TIMESTAMP  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA12 INDEX IN TSC_INDEX12
;


COMMENT ON TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE IS 'Which accounts are in which households.  This is derived from the household-party and party-account bridges.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE.household_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE.change_begin_date IS 'Date from which this row was valid.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE.change_end_date IS 'Date to which this row was valid.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE.change_current_ind IS 'Is this the current instance (Y/N)'
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
	ADD CONSTRAINT  XPKHOUSEHO  PRIMARY KEY (household_key,account_key,change_begin_date,segment_id)
;

CREATE INDEX AMLCORE.XIF1HOUSEHO ON AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key  ASC,
	segment_id  ASC
);



CREATE INDEX AMLCORE.XIF2HOUSEHO ON AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	account_key  ASC,
	segment_id  ASC
);


CREATE TABLE AMLCORE.FSC_HOUSEHOLD_DIM
(
	household_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	household_number  VARCHAR(50)  ,
	household_type_desc  VARCHAR(20)  ,
	street_address_1  VARCHAR(35)  ,
	street_address_2  VARCHAR(35)  ,
	street_city_name  VARCHAR(35)  ,
	street_state_code  CHAR(3)  ,
	street_state_name  VARCHAR(35)  ,
	street_postal_code  VARCHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	phone_number_1  VARCHAR(25)  ,
	phone_number_2  VARCHAR(25)  ,
	head_of_household_name  VARCHAR(35)  ,
	employee_ind  CHAR(1)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
)  IN TSC_DATA13 INDEX IN TSC_INDEX13 ;


COMMENT ON TABLE AMLCORE.FSC_HOUSEHOLD_DIM IS 'Any grouping of parties or accounts which is considered relevant for anti-money laundering purposes. A party can be in multiple households, but only one of a given type.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.household_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.household_number IS 'Source system identifier (if available).'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.household_type_desc IS 'Client-specified household categorization.  e.g. "Common Address", "Common Phone", "Marketing"'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_address_1 IS 'Household Physical Address - Line 1.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_address_2 IS 'Household Physical Address - Line 2.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_city_name IS 'Household Physical Address - City.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_state_code IS 'Household Physical Address - State.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_state_name IS 'Household Physical Address - State/Province etc name..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_postal_code IS 'Household Physical Address - Postal Code.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_country_code IS 'Household Physical Address - Country Code (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.street_country_name IS 'Street Country - Name (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.phone_number_1 IS 'Phone 1 (home?).'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.phone_number_2 IS 'Phone 2(business?).'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.head_of_household_name IS 'Name of head of household..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.employee_ind IS 'Is the party also an employee of the firm? Y/N.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.change_begin_date IS 'Date from which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.change_end_date IS 'Date to which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_DIM.change_current_ind IS 'Is this the current instance (Y/N).'
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_DIM
	ADD CONSTRAINT  XPKHOUSEHOLD  PRIMARY KEY (household_key,segment_id)
;


CREATE INDEX AMLCORE.XIE1HOUSEHOLD ON AMLCORE.FSC_HOUSEHOLD_DIM
(
	household_number  ASC,
	change_current_ind  ASC
)
;


CREATE INDEX AMLCORE.XIE3HOUSEHOLD ON AMLCORE.FSC_HOUSEHOLD_DIM
(
	head_of_household_name  ASC
)
;


CREATE INDEX AMLCORE.XIE4HOUSEHOLD ON AMLCORE.FSC_HOUSEHOLD_DIM
(
	phone_number_1  ASC
)
;


CREATE INDEX AMLCORE.XIE5HOUSEHOLD ON AMLCORE.FSC_HOUSEHOLD_DIM
(
	phone_number_2  ASC
)
;


CREATE TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key  BIGINT  NOT NULL,
	household_key  BIGINT  NOT NULL,
	change_begin_date TIMESTAMP  NOT NULL,
	segment_id  VARCHAR(128) NOT NULL DEFAULT CURRENT_USER,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
)  IN TSC_DATA14 INDEX IN TSC_INDEX14 ;


COMMENT ON TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE IS 'Which parties are included in which households.'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE.party_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE.household_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE.change_begin_date IS 'Date from which this row was valid'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE.change_end_date IS 'Date to which this row was valid'
;


COMMENT ON COLUMN AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE.change_current_ind IS 'Is this the current instance (Y/N).'
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
	ADD CONSTRAINT  XPKHOUSEHOLD_CUSTO  PRIMARY KEY (party_key,household_key,change_begin_date,segment_id)
;


CREATE INDEX AMLCORE.XIF1HC_BRIDGE ON AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF2HC_BRIDGE ON AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	household_key  ASC,
	segment_id  ASC
);


CREATE TABLE AMLCORE.FSC_LOCATION_WATCH_LIST_DIM
(
	location_watch_list_key  BIGINT  NOT NULL,
	location_watch_list_number  VARCHAR(35)  NOT NULL,
	watch_list_name  CHAR(4)  NOT NULL,
	program  VARCHAR(20)  ,
	country_code  CHAR(3)  ,
	country_name  VARCHAR(100)  ,
	match_code_country_name  VARCHAR(15)  ,
	create_date TIMESTAMP  ,
	update_date TIMESTAMP  ,
	exclude_ind  CHAR(1)  NOT NULL,
	change_begin_date TIMESTAMP  NOT NULL,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA15 INDEX IN TSC_INDEX15;


COMMENT ON TABLE AMLCORE.FSC_LOCATION_WATCH_LIST_DIM IS 'Countries appearing on selected country watch lists (e.g. NCCT list).'
;


COMMENT ON COLUMN AMLCORE.FSC_LOCATION_WATCH_LIST_DIM.location_watch_list_key IS 'Surrogate key..'
;


ALTER TABLE AMLCORE.FSC_LOCATION_WATCH_LIST_DIM
	ADD CONSTRAINT  XPKFSC_LOCATION_WA  PRIMARY KEY (location_watch_list_key)
;


CREATE TABLE AMLCORE.FSC_MONTH_DIM
(
	month_key  NUMERIC(6,0)  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	month_and_year  CHAR(6)  ,
	month_name  VARCHAR(9)  ,
	month_name_3c  CHAR(3)  ,
	quarter_name_2c  CHAR(2)  ,
	quarter_name_4c  CHAR(4)  ,
	year_2c  CHAR(2)  ,
	year_4c  CHAR(4)  ,
	current_month_ind  CHAR(1)  
) IN TSC_DATA01 INDEX IN TSC_INDEX01 ;


COMMENT ON TABLE AMLCORE.FSC_MONTH_DIM IS 'Calendar month table.'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.month_key IS 'Meaningful surrogate key of format yyyymm.'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.month_and_year IS 'Combined month and year e.g. 032003 (March 2003)'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.month_name IS 'e.g. March'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.month_name_3c IS 'e.g. MAR'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.quarter_name_2c IS 'e.g. Q1'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.quarter_name_4c IS 'e.g. QTR1'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.year_2c IS 'e.g. 03'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.year_4c IS 'e.g. 2003'
;


COMMENT ON COLUMN AMLCORE.FSC_MONTH_DIM.current_month_ind IS 'Is this the current month Y/N.'
;


ALTER TABLE AMLCORE.FSC_MONTH_DIM
	ADD CONSTRAINT  XPKMONTH_DIM  PRIMARY KEY (month_key,segment_id)
;


CREATE TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key  BIGINT  NOT NULL,
	party_key  BIGINT  NOT NULL,
	role_key  NUMERIC(2)  NOT NULL,
	change_begin_date TIMESTAMP  NOT NULL,
	segment_id  VARCHAR(128) NOT NULL DEFAULT CURRENT_USER,
	role_desc  VARCHAR(20)  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
)  IN TSC_DATA18 INDEX IN TSC_INDEX18;


COMMENT ON TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE IS 'Which parties play which roles on an account.  Types include: Primary Owner, Secondary Owner, Signer, Beneficiary, Insured.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.party_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.role_key IS 'Ideintifier for the role_desc.  Added to allow a party to play multiple roles on an account.  May want to break this out into a ROLE_DIM post 1.3.

Starter Values are:
1-PRIMARY OWNER
2-SECONDARY OWNER
3-SIGNER
4-BENEFICIARY
5-INSURED'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.change_begin_date IS 'Date from which this row was valid'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.role_desc IS 'Role that the party plays on an account.

Starter values are:

Starter Values are:
1-PRIMARY OWNER
2-SECONDARY OWNER
3-SIGNER
4-BENEFICIARY
5-INSURED'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.change_end_date IS 'Date to which this row was valid'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE.change_current_ind IS 'Is this the current instance (Y/N).'
;


ALTER TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
	ADD CONSTRAINT  XPKCUSTOMER_ACCOUN  PRIMARY KEY (account_key,party_key,role_key,change_begin_date,segment_id)
;

CREATE INDEX AMLCORE.XIF1CA_BRIDGE ON AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	party_key  ASC,
	segment_id  ASC
);


CREATE INDEX AMLCORE.XIF2CA_BRIDGE ON AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key  ASC,
	segment_id  ASC
);


CREATE TABLE AMLCORE.FSC_PARTY_DIM
(
	party_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128) NOT NULL DEFAULT CURRENT_USER,
	party_number  VARCHAR(50)  NOT NULL,
	party_type_desc  VARCHAR(20)  NOT NULL,
	party_tax_id  VARCHAR(35)  ,
	party_tax_id_type_code  CHAR(1)  ,
	party_identification_id  VARCHAR(35)  ,
	party_identification_type_desc  CHAR(4)  ,
	party_id_state_code  CHAR(3)  ,
	party_date_of_birth TIMESTAMP  ,
	party_first_name  VARCHAR(35)  ,
	party_last_name  VARCHAR(35)  ,
	party_middle_name  VARCHAR(35)  ,
	party_name  VARCHAR(35)  ,
	doing_business_as_name  VARCHAR(35)  ,
	party_status_desc  VARCHAR(20)  ,
	ultimate_parent_name  VARCHAR(35)  ,
	match_code_organization  CHAR(20)  ,
	match_code_individual  CHAR(15)  ,
	match_code_street_address  CHAR(40)  ,
	match_code_mailing_address  CHAR(40)  ,
	street_address_1  VARCHAR(35)  ,
	street_address_2  VARCHAR(35)  ,
	street_city_name  VARCHAR(35)  ,
	street_state_code  CHAR(3)  ,
	street_state_name  VARCHAR(35)  ,
	street_postal_code  CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	mailing_address_1  VARCHAR(35)  ,
	mailing_address_2  VARCHAR(35)  ,
	mailing_city_name  VARCHAR(35)  ,
	mailing_state_code  CHAR(3)  ,
	mailing_state_name  VARCHAR(35)  ,
	mailing_postal_code  CHAR(10)  ,
	mailing_country_code  CHAR(3)  ,
	mailing_country_name  VARCHAR(100)  ,
	residence_country_code  CHAR(3)  ,
	residence_country_name  VARCHAR(100)  ,
	citizenship_country_code  CHAR(3)  ,
	citizenship_country_name  VARCHAR(100)  ,
	org_country_of_business_code  CHAR(3)  ,
	org_country_of_business_name  VARCHAR(100)  ,
	employee_ind  CHAR(1)  ,
	employee_number  VARCHAR(20)  ,
	employer_name  VARCHAR(35)  ,
	employer_phone_number  VARCHAR(25)  ,
	email_address  VARCHAR(35)  ,
	occupation_desc  VARCHAR(35)  ,
	industry_code  CHAR(10)  ,
	industry_desc  VARCHAR(255)  ,
	phone_number_1  VARCHAR(25)  ,
	phone_number_2  VARCHAR(25)  ,
	phone_number_3  VARCHAR(25)  ,
	annual_income_amount  NUMERIC(10,0)  ,
	net_worth_amount  NUMERIC(10,0)  ,
	marital_status_desc  VARCHAR(20)  ,
	last_contact_date TIMESTAMP  ,
	politically_exposed_person_ind  CHAR(1)  NOT NULL DEFAULT 'N',
	non_profit_org_ind  CHAR(1)  ,
	customer_since_date TIMESTAMP  ,
	last_susp_actv_rpt_date TIMESTAMP  ,
	last_cash_trans_rpt_date TIMESTAMP  ,
	last_risk_assessment_date TIMESTAMP  ,
	risk_classification  NUMERIC(1)  ,
	change_begin_date TIMESTAMP  ,
	change_end_date TIMESTAMP  NOT NULL DEFAULT TIMESTAMP('59990101000000')
,
	change_current_ind  CHAR(1)  NOT NULL
) IN TSC_DATA19 INDEX IN TSC_INDEX19 ;


COMMENT ON TABLE AMLCORE.FSC_PARTY_DIM IS 'Any individual or organization that plays a role on an account.  Types include: Primary Owners, Secondary Owners, Authorized Signers, Beneficiaries, Insured.

'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_key IS 'System generated surrogate identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_number IS 'Source system''s customer identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_type_desc IS 'Describes the nature of the party. 

Must be set to either INDIVIDUAL or
ORGANIZATION.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_tax_id IS 'Tax Identification Number.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_tax_id_type_code IS 'E (EIN)  or S(SSN).'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_identification_id IS 'Customer identification number used to open account e.g. driver''s license number..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_identification_type_desc IS 'DRIVERS LICENSE
MILITARY ID
PASSPORT
EMPLOYER ID
GREEN CARD
GOVERNMENT ID
SCHOOL ID
STATE ID
UNION ID
OTHER'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_id_state_code IS 'State of Driver''s license if license used for id in account opening process..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_date_of_birth IS 'Customer date of birth.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_first_name IS 'Customer''s first name..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_last_name IS 'Customer''s last name.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_middle_name IS 'Customer''s middle name.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_name IS 'Full customer name e.g. "John R Smith" or "ACME Inc"..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.doing_business_as_name IS 'Customer''s doing business as name if different to legal name..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.party_status_desc IS 'Active, Dormant, Ex-Customer..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.ultimate_parent_name IS 'Which entity is the ultimate parent entity. (MS)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.match_code_organization IS 'Match code column for orginization names.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.match_code_individual IS 'Match code names for individuals.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.match_code_street_address IS 'Match code address for individuals or organizations.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.match_code_mailing_address IS 'Match code address for individuals or organizations.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_address_1 IS 'Physical Address - Line 1.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_address_2 IS 'Physical Address - Line 2.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_city_name IS 'Physical Address - City.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_state_code IS 'Physical Address - State.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_state_name IS 'State/Province etc name'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_postal_code IS 'Physical Address - Postal Code.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_country_code IS 'Physical Address - Country Code (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.street_country_name IS 'Street Address - Country Name (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_address_1 IS 'Mailing Address - Line 1.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_address_2 IS 'Mailing Address - Line2.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_city_name IS 'Mailing Address - City.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_state_code IS 'Mailing Address - State.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_state_name IS 'State/Province etc name'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_postal_code IS 'Mailing Address - Postal Code.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_country_code IS 'Mailing Address - Country (ISO).'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.mailing_country_name IS 'Mailing Address Country Name (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.residence_country_code IS 'Country of residence (ISO-3) for an individual.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.residence_country_name IS 'Name of Country of residence for individual (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.citizenship_country_code IS 'Country of Citizenship (ISO-3) for individual.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.citizenship_country_name IS 'Country of citizenship - name - for individual (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.org_country_of_business_code IS 'Primary country of business code - organizations only (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.org_country_of_business_name IS 'Primary country of business name - organizations only (ISO)'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.employee_ind IS 'Is the party also an employee of the firm? Y/N.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.employee_number IS 'If the Party is also an employee this is the employee number.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.employer_name IS 'Employer Name.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.employer_phone_number IS 'Employer Phone Number.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.email_address IS 'Customer email address.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.occupation_desc IS 'military.
religous
self employed
self employed prof/tech
self employed management
self employed clerical
professional
administrative 
management
clerical
craftsman
student
housewife
retired
farmer'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.industry_code IS 'Industry code of the Party e.g. SIC Code or NAICS code'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.industry_desc IS 'Industry description of the party e.g. SIC or NAICS code description.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.phone_number_1 IS 'Customer Phone Number 1'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.phone_number_2 IS 'Customer Phone 2'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.phone_number_3 IS 'Customer Phone 3'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.annual_income_amount IS 'Party''s annual income.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.net_worth_amount IS 'Party''s net worth as stated on the account application.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.marital_status_desc IS 'e.g. Married, Single etc'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.last_contact_date IS 'Date the party was last contacted.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.politically_exposed_person_ind IS 'Is this person in a senior political position or related to a senior political person in some way? Y/N
'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.non_profit_org_ind IS 'Is this party designated a non-profit organization e.g. a charity (Y/N).'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.customer_since_date IS 'Date the party first became a customer of the financial institution..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.last_susp_actv_rpt_date IS 'For this party, the date the last Suspicious Activity Report was filed with govt.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.last_cash_trans_rpt_date IS 'For this party, the date the last Cash Transaction Report was filed with govt.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.last_risk_assessment_date IS 'The last date that this party''s risk category was reviewed by an AML user through the UI. The last_risk_assessment_date column will be updated as a type-1 change even if no change to the risk_category occurs as a result of the review. This documents the '
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.risk_classification IS 'This column is updated by the risk assessment UI. If this review results in a change to the risk_category for the party, then a type-2 change will be performed on the risk_category value to preserve a history of the old value and the time of the change.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.change_begin_date IS 'Date from which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.change_end_date IS 'Date to which this row was valid..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_DIM.change_current_ind IS 'Is this the current instance (Y/N).'
;


ALTER TABLE AMLCORE.FSC_PARTY_DIM
	ADD CONSTRAINT  XPKCUSTOMER  PRIMARY KEY (party_key,segment_id)
;


CREATE INDEX AMLCORE.XIE12CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	party_name  ASC
)
;


CREATE INDEX AMLCORE.XIE13CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	party_number  ASC
)
;


CREATE INDEX AMLCORE.XIE14CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	party_tax_id  ASC
)
;


CREATE INDEX AMLCORE.XIE15CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	match_code_mailing_address  ASC
)
;


CREATE INDEX AMLCORE.XIE16CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	match_code_street_address  ASC
)
;


CREATE INDEX AMLCORE.XIE17CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	phone_number_1  ASC
)
;


CREATE INDEX AMLCORE.XIE18CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	phone_number_2  ASC
)
;


CREATE INDEX AMLCORE.XIE19CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	phone_number_3  ASC
)
;


CREATE INDEX AMLCORE.XIE20CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	employer_name  ASC
)
;


CREATE INDEX AMLCORE.XIE21CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	match_code_individual  ASC
)
;


CREATE INDEX AMLCORE.XIE22CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	match_code_organization  ASC
)
;


CREATE INDEX AMLCORE.XIE23CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	employer_phone_number  ASC
)
;


CREATE INDEX AMLCORE.XIE7CUSTOMER ON AMLCORE.FSC_PARTY_DIM
(
	party_last_name  ASC
)
;


CREATE TABLE AMLCORE.FSC_PARTY_PROFILE_FACT
(
	party_number  VARCHAR(50)  NOT NULL,
	month_key  NUMERIC(6,0)  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	aggregate_assets_amount  NUMERIC(18,5)  ,
	transactions_count  NUMERIC(10,0)  ,
	deposits_count  NUMERIC(10,0)  ,
	withdrawals_count  NUMERIC(10,0)  ,
	wires_count  NUMERIC(10,0)  ,
	cash_transactions_count  NUMERIC(10,0)  ,
	account_value_amount  NUMERIC(10,0)  ,
	total_transactions_amount  NUMERIC(18,5)  ,
	total_credits_amount  NUMERIC(10,0)  ,
	total_debits_amount  NUMERIC(18,5)  ,
	total_cash_debits_amount  NUMERIC(18,5)  ,
	total_cash_credits_amount  NUMERIC(18,5)  ,
	total_wire_credits_amount  NUMERIC(18,5)  ,
	total_wire_debits_amount  NUMERIC(18,5)  ,
	largest_credit_amount  NUMERIC(18,5)  ,
	largest_debit_amount  NUMERIC(18,5)  ,
	funds_payment_svcs_count  BIGINT  ,
	funds_transfer_count  BIGINT  ,
	monetary_instrument_count  BIGINT  
) IN TSC_DATA20 INDEX IN TSC_INDEX20 ;


COMMENT ON TABLE AMLCORE.FSC_PARTY_PROFILE_FACT IS 'A monthly snapshot of a party''s transactional activity.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_PROFILE_FACT.party_number IS 'Source system''s customer identifier..'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_PROFILE_FACT.month_key IS 'Meaningful surrogate key of format yyyymm.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_PROFILE_FACT.aggregate_assets_amount IS 'Total assets across all accounts.  Only includes assets, does not include loan amounts.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_PROFILE_FACT.total_wire_credits_amount IS 'Total Wire Credits ($) to all accounts for the party during the period.'
;


COMMENT ON COLUMN AMLCORE.FSC_PARTY_PROFILE_FACT.total_wire_debits_amount IS 'Total Wire debits ($) to all accounts for the party during the period.'
;


ALTER TABLE AMLCORE.FSC_PARTY_PROFILE_FACT
	ADD CONSTRAINT  XPKFSC_PARTY_PROFI  PRIMARY KEY (party_number,month_key,segment_id)
;


CREATE TABLE AMLCORE.FSC_TIME_DIM
(
	time_key  NUMERIC(6)  NOT NULL,
	time_hhmmss  CHAR(6)  ,
	time_hh  CHAR(2)  ,
	time_mm  CHAR(2)  ,
	time_ss  CHAR(2)  ,
	time_am_pm  CHAR(2)  
) IN TSC_DATA01 INDEX IN TSC_INDEX01
;


COMMENT ON TABLE AMLCORE.FSC_TIME_DIM IS 'The seconds in a day.'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_hhmmss IS 'hour,min,sec'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_hh IS 'hour'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_mm IS 'minutes'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_ss IS 'seconds'
;


COMMENT ON COLUMN AMLCORE.FSC_TIME_DIM.time_am_pm IS 'am or pm'
;


ALTER TABLE AMLCORE.FSC_TIME_DIM
	ADD CONSTRAINT  XPKTIME_DIM  PRIMARY KEY (time_key)
;


CREATE INDEX AMLCORE.XIE1TIME_DIM ON AMLCORE.FSC_TIME_DIM
(
	time_hhmmss  ASC
)
;


CREATE TABLE AMLCORE.FSC_TRANSACTION_DIM
(
	transaction_key  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL,
	date_key  NUMERIC(8,0)  NOT NULL,
	transaction_reference_number  VARCHAR(50)  NOT NULL,
	transaction_description  VARCHAR(255)  ,
	security_name  VARCHAR(35)  ,
	deal_number  VARCHAR(35)  
) IN TSC_DATA21 INDEX IN TSC_INDEX21
;


COMMENT ON TABLE AMLCORE.FSC_TRANSACTION_DIM IS 'A supplementary table to the transaction facts used to capture additional, typically verbose, data that about a transaction.  Storing this data here helps keep the fact table "skinny" and therefore smaller than they would otherwise be.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.transaction_key IS 'Surrogate key..'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd

This column has been added to this table to enable table partitioning.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.transaction_reference_number IS 'Source system''s transaction identifier e.g. deposit number'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.transaction_description IS 'Free form text description of trade.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.security_name IS 'Name of the equity, bond, currency etc bought or sold.  Could use ticker if preferred.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_DIM.deal_number IS 'Number identifying a trade plus associated settlements.  e.g. Trade is to buy 1mm Euros; settled with two wires each of $500K.  All three transactions are part of the same deal and therefore will have the same deal number.'
;


ALTER TABLE AMLCORE.FSC_TRANSACTION_DIM
	ADD CONSTRAINT  XPKFSC_TRANSACTION  PRIMARY KEY (transaction_key,segment_id)
;


CREATE UNIQUE INDEX AMLCORE.XAK1TRAN_DIM ON AMLCORE.FSC_TRANSACTION_DIM
(
	transaction_reference_number,
	segment_id
)
;

CREATE INDEX AMLCORE.XIF1TRAN_DIM ON AMLCORE.FSC_TRANSACTION_DIM
(
	date_key,
	segment_id
)
;

CREATE TABLE AMLCORE.FSC_TRANSACTION_STATUS_DIM
(
	transaction_status_key  NUMERIC(5)  NOT NULL,
	status_desc  VARCHAR(20)  ,
	status_reason_desc  VARCHAR(35)  
)  IN TSC_DATA01 INDEX IN TSC_INDEX01;


COMMENT ON TABLE AMLCORE.FSC_TRANSACTION_STATUS_DIM IS 'The outcome of a transaction e.g. SUCCESS or FAILURE because EXCEEDED DAILY LIMIT.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_STATUS_DIM.transaction_status_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_STATUS_DIM.status_desc IS 'e.g. SUCCESS, DENIED'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_STATUS_DIM.status_reason_desc IS 'e.g. EXCEEDED DAILY LIMIT'
;


ALTER TABLE AMLCORE.FSC_TRANSACTION_STATUS_DIM
	ADD CONSTRAINT  XPKFSC_TRANSACTION  PRIMARY KEY (transaction_status_key)
;


CREATE INDEX AMLCORE.XIE1FSC_TRANSACTIO ON AMLCORE.FSC_TRANSACTION_STATUS_DIM
(
	status_desc  ASC
)
;


CREATE TABLE AMLCORE.FSC_TRANSACTION_TYPE_DIM
(
	transaction_type_key  BIGINT  NOT NULL,
	funds_securities_code  CHAR(1)  ,
	funds_securities_desc  VARCHAR(20)  ,
	transaction_cdi_code  CHAR(1)  ,
	transaction_cdi_desc  VARCHAR(20)  ,
	primary_medium_desc  VARCHAR(20)  ,
	secondary_medium_desc  VARCHAR(20)  ,
	mechanism_desc  VARCHAR(20)  
)  IN TSC_DATA01 INDEX IN TSC_INDEX01;


COMMENT ON TABLE AMLCORE.FSC_TRANSACTION_TYPE_DIM IS 'A fixed classification of transactions used to analyze transactions in a consistent manner.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.funds_securities_code IS 'F (funds i.e. money) vs S (securities)'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.funds_securities_desc IS 'Descriptive version of the code for UI display.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.transaction_cdi_code IS 'D-Debit, C-Credit, E-Event
'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.transaction_cdi_desc IS 'Descriptive version of the code for UI display.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.primary_medium_desc IS 'e.g. Cash, Check.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.secondary_medium_desc IS 'e.g. US, non_USD, personal, cashiers, counter etc.'
;


COMMENT ON COLUMN AMLCORE.FSC_TRANSACTION_TYPE_DIM.mechanism_desc IS 'e.g. Teller, ATM, Online'
;


ALTER TABLE AMLCORE.FSC_TRANSACTION_TYPE_DIM
	ADD CONSTRAINT  XPKTRANSACTION  PRIMARY KEY (transaction_type_key)
;


CREATE INDEX AMLCORE.XIE1TRAN_TP ON AMLCORE.FSC_TRANSACTION_TYPE_DIM
(
	funds_securities_code  ASC,
	funds_securities_desc  ASC
)
;


CREATE INDEX AMLCORE.XIE2TRAN_TP ON AMLCORE.FSC_TRANSACTION_TYPE_DIM
(
	transaction_cdi_code  ASC,
	transaction_cdi_desc  ASC
)
;


CREATE INDEX AMLCORE.XIE3FSC_TRANSACTIO ON AMLCORE.FSC_TRANSACTION_TYPE_DIM
(
	primary_medium_desc  ASC,
	secondary_medium_desc  ASC
)
;

CREATE TABLE AMLCORE.FSC_PARTY_SEQUENCE
(
	next_sequence_id  BIGINT  NOT NULL,
	segment_id  VARCHAR(128)  NOT NULL DEFAULT CURRENT_USER
) IN TSK_DATA21 INDEX IN TSK_INDEX21;

COMMENT ON TABLE AMLCORE.FSC_PARTY_SEQUENCE IS 'The next identifier available to be used as a party_key in fsc_party_dim. Used by both the ETL process and the UI for generating new fsc_party_dim records.';
COMMENT ON COLUMN AMLCORE.FSC_PARTY_SEQUENCE.next_sequence_id IS 'The next identifier available to be used as a party_key in fsc_party_dim. The user must read this value and immediately increment, update and commit to allow the next user access.';
COMMENT ON COLUMN AMLCORE.FSC_PARTY_SEQUENCE.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.';


create view amlcore.FSC_ACCOUNT_PRIMARY_OWNER_VIEW as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1 and p.segment_id = b.segment_id
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y' and b.segment_id = a.segment_id
where p.change_current_ind = 'Y'
;


COMMENT ON TABLE AMLCORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW IS 'Contains the current (change_current_ind = Y) mapping between accounts (by account_number) and their primary owners (also by account_number). '
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_131 FOREIGN KEY (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_132 FOREIGN KEY (date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_133 FOREIGN KEY (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_140 FOREIGN KEY (time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_157 FOREIGN KEY (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_158 FOREIGN KEY (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_160 FOREIGN KEY (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD CONSTRAINT R_161 FOREIGN KEY (country_key) REFERENCES AMLCORE.FSC_COUNTRY_DIM(country_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT
	ADD CONSTRAINT R_6 FOREIGN KEY (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_165 FOREIGN KEY (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_166 FOREIGN KEY (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_167 FOREIGN KEY (trade_date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_168 FOREIGN KEY (execution_time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_169 FOREIGN KEY (transaction_currency_key) REFERENCES AMLCORE.FSC_CURRENCY_DIM(currency_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_170 FOREIGN KEY (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_171 FOREIGN KEY (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_184 FOREIGN KEY (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
		ON DELETE NO ACTION
		ON UPDATE NO ACTION
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD CONSTRAINT R_186 FOREIGN KEY (associate_key,segment_id) REFERENCES AMLCORE.FSC_ASSOCIATE_DIM(associate_key,segment_id)
		ON DELETE NO ACTION
		ON UPDATE NO ACTION
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD CONSTRAINT R_175 FOREIGN KEY (bank_key,segment_id) REFERENCES AMLCORE.FSC_BANK_DIM(bank_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD CONSTRAINT R_176 FOREIGN KEY (transaction_key,segment_id) REFERENCES AMLCORE.FSC_CASH_FLOW_FACT(transaction_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_111 FOREIGN KEY (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_113 FOREIGN KEY (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_149 FOREIGN KEY (executing_party_key,segment_id) REFERENCES AMLCORE.FSC_PARTY_DIM(party_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_154 FOREIGN KEY (associate_key,segment_id) REFERENCES AMLCORE.FSC_ASSOCIATE_DIM(associate_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_159 FOREIGN KEY (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_178 FOREIGN KEY (remitter_ext_party_key,segment_id) REFERENCES AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM(ext_party_account_key,segment_id);


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_179 FOREIGN KEY (beneficiary_ext_party_key,segment_id) REFERENCES AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM(ext_party_account_key,segment_id);


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT FK_ACCOUNT_CREDIT FOREIGN KEY (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT FK_BRANCH_CREDIT FOREIGN KEY (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT FK_DATE_CREDIT FOREIGN KEY (date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT FK_TIME_CREDIT FOREIGN KEY (time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_85 FOREIGN KEY (transaction_currency_key) REFERENCES AMLCORE.FSC_CURRENCY_DIM(currency_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD CONSTRAINT R_126 FOREIGN KEY (country_key) REFERENCES AMLCORE.FSC_COUNTRY_DIM(country_key)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_CLASSIFIER_FACT
	ADD CONSTRAINT R_181 FOREIGN KEY (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
		ON DELETE NO ACTION
		ON UPDATE NO ACTION
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
	ADD CONSTRAINT R_162 FOREIGN KEY (household_key,segment_id) REFERENCES AMLCORE.FSC_HOUSEHOLD_DIM(household_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
	ADD CONSTRAINT R_163 FOREIGN KEY (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
	ADD CONSTRAINT FK_CUST_HH_BRDIGE FOREIGN KEY (party_key,segment_id) REFERENCES AMLCORE.FSC_PARTY_DIM(party_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
	ADD CONSTRAINT R_47 FOREIGN KEY (household_key,segment_id) REFERENCES AMLCORE.FSC_HOUSEHOLD_DIM(household_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
	ADD CONSTRAINT FK_CUST_ACCT_BRIDG FOREIGN KEY (party_key,segment_id) REFERENCES AMLCORE.FSC_PARTY_DIM(party_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
	ADD CONSTRAINT R_8 FOREIGN KEY (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;


ALTER TABLE AMLCORE.FSC_PARTY_PROFILE_FACT
	ADD CONSTRAINT R_155 FOREIGN KEY (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
		ON DELETE RESTRICT
		ON UPDATE RESTRICT
;

set schema BANK1KCTR;
--Create Core table views for each multibank segment.
create view BANK1CORE.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK1CORE.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK1CORE.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK1CORE.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK1CORE.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK1CORE.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK1KCTR'; 
create view BANK1CORE.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK1CORE.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK1CORE.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK1CORE.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK1KCTR';

create view BANK2CORE.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK2CORE.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK2CORE.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK2CORE.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK2CORE.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK2CORE.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK2CORE.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK2KCTR';
create view BANK2CORE.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK2CORE.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK2CORE.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK2KCTR';

create view BANK1KCTR.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK1KCTR.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK1KCTR.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK1KCTR.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK1KCTR.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK1KCTR.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK1KCTR.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK1KCTR.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK1KCTR.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK1KCTR';

create view BANK2KCTR.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK2KCTR.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK2KCTR.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK2KCTR.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK2KCTR.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK2KCTR.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK2KCTR.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK2KCTR';
create view BANK2KCTR.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK2KCTR.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK2KCTR.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK2KCTR';

create view BANK1CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK1KCTR'
and b.segment_id = 'BANK1KCTR'
and a.segment_id = 'BANK1KCTR'
;

comment on TABLE BANK1CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW is 'Contains the current (change_current_ind = Y) mapping between accounts (by account_number) and their primary owners (also by account_number). '
;
comment on column BANK1CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.account_number is '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number.'
;
comment on column BANK1CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.current_primary_owner_number is 'Source system''s customer identifier.'
;


create view BANK2CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK2KCTR'
and b.segment_id = 'BANK2KCTR'
and a.segment_id = 'BANK2KCTR'
;

comment on TABLE BANK2CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW is 'Contains the current (change_current_ind = Y) mapping between accounts (by account_number) and their primary owners (also by account_number). '
;
comment on column BANK2CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.account_number is '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number.'
;
comment on column BANK2CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.current_primary_owner_number is 'Source system''s customer identifier.'
;



create view BANK1KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK1KCTR'
and b.segment_id = 'BANK1KCTR'
and a.segment_id = 'BANK1KCTR'
;

comment on TABLE BANK1KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW is 'Contains the current (change_current_ind = Y) mapping between accounts (by account_number) and their primary owners (also by account_number). '
;
comment on column BANK1KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.account_number is '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number.'
;
comment on column BANK1KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.current_primary_owner_number is 'Source system''s customer identifier.'
;



create view BANK2KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK2KCTR'
and b.segment_id = 'BANK2KCTR'
and a.segment_id = 'BANK2KCTR'
;

comment on TABLE BANK2KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW is 'Contains the current (change_current_ind = Y) mapping between accounts (by account_number) and their primary owners (also by account_number). '
;
comment on column BANK2KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.account_number is '"Natural Key" from source system.  This may be concatenated e.g. division, branch, acct number.'
;
comment on column BANK2KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW.current_primary_owner_number is 'Source system''s customer identifier.'
;


CREATE VIEW BANK1KCTR.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK1KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK1KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK1KCTR'
;


CREATE VIEW BANK2KCTR.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK2KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK2KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK2KCTR'
;


CREATE VIEW BANK1CORE.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK1KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK1KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK1KCTR'
;


CREATE VIEW BANK2CORE.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK2KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK2KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK2KCTR'
;



commit;
